*********************
Common Customizations
*********************

When starting a new TOM, we're sure there are a few things a user might want to change right away. Fortunately, we've anticipated that! Here are some guides to get you started:

* Not happy with the appearance? Jump straight in with :doc:`customizing TOM Templates <customize_templates>`. You may want to take a look at the available Template Tags in each modules' respective `API Documentation <https://tom-toolkit.readthedocs.io/en/stable/modules/modules.html>`_ to see what you can do.
* Need another view? Take a peek at :doc:`Adding Pages <adding_pages>`.
* Want to automate something? Look at the :doc:`Automation Guide <automation>`. Feeling bold? Set up :doc:`background tasks <../advanced/backgroundtasks>`.
* SQLite not meeting your needs? Check out Django's documentation on `databases <https://docs.djangoproject.com/en/2.2/topics/security/>`_.